#
# spec file for package difftastic
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 munix9@googlemail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           difftastic
Version:        0.64.0
Release:        1.1
Summary:        A structural diff that understands syntax
License:        Apache-2.0 AND MIT
URL:            https://difftastic.wilfred.me.uk/
Source0:        https://github.com/Wilfred/difftastic/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Patch1:         reproducible.patch
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  jq
BuildRequires:  libstdc++6-devel-gcc13
BuildRequires:  rust >= 1.74.1
BuildRequires:  shared-mime-info
Requires:       shared-mime-info
%if 0%{?suse_version} >= 1600
Suggests:       %{name}-doc
%endif
ExclusiveArch:  %{rust_tier1_arches}

%description
Difftastic is a structural diff tool that compares files based on their syntax.

%if 0%{?suse_version} >= 1600
%package doc
Summary:        Documentation for difftastic
BuildRequires:  mdbook
BuildArch:      noarch

%description doc
This package contains the documentation for difftastic.
%endif

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

%if 0%{?suse_version} >= 1600
cd manual
mdbook build
%endif

%install
install -D -m 0755 -t %{buildroot}%{_bindir} target/release/difft
install -D -m 0644 -t %{buildroot}%{_mandir}/man1 difft.1

%if 0%{?suse_version} >= 1600
rm -v manual/book/.nojekyll
%fdupes -s manual/book
%endif

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/difft
%{_mandir}/man1/difft.1%{?ext_man}

%if 0%{?suse_version} >= 1600
%files doc
%license LICENSE
%doc manual/book
%endif

%changelog
* Sat Jun 28 2025 munix9@googlemail.com
- update to 0.64.0:
  Parsing
  * Updated to the latest tree-sitter parser for Erlang, F#, Gleam,
    Pascal and Swift.
  * File detection is now stricter for UTF-8, and recognises more
    compression file types as binary (e.g. zstd or bzip2).
  * Added support for Verilog and SystemVerilog.
  Internal
  * Difftastic has switched from MiMalloc to Jemalloc for allocation.
    This is modest performance regression (up to 20%% longer runtime
    in testing). Jemalloc is currently easier to build (see issue
    [#805]) and has fewer pathological performance corner cases.
- Add man page
* Fri Mar  7 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to avoid a race (boo#1102408)
* Fri Feb 14 2025 munix9@googlemail.com
- update to 0.63.0:
  Diffing
  * When diffing directories, difftastic now ignores the .git
    directory.
  Display
  * Fixed an issue where --display=side-by-side-show-both would
    not use a two-column display when one file was empty.
  Command Line Interface
  * Difftastic no longer accepts the --missing-as-empty argument.
    This argument has had no effect since 0.46.
  Parsing
  * File detection now supports Windows-1252 encoded text (an
    extension of ISO-8859-1), and is stricter about UTF-16 detection.
  * Updated to the latest tree-sitter parser for Elixir, LaTeX,
    Make, Nix, Rust and YAML.
* Fri Dec 27 2024 munix9@googlemail.com
- update to 0.62.0:
  * Improved handling of multiline strings, which could cause a
    crash if they occurred at the end of the file. This was
    particularly noticeable with YAML.
  * Improved language detection when one argument is a named pipe.
  * Updated to the latest tree-sitter parser for Bash, C, C++, C#,
    CSS, Go, Haskell, HTML, Java, JavaScript, JSON, Julia, Lua,
    Objective-C, OCaml, PHP, Python, Ruby, Scala, TOML, TypeScript
    and XML.
  * Improved syntax highlighting, particularly for keywords.
- update to 0.61.0:
  * Side-by-side display is now smarter on very wide terminals
    when the content is narrow.
  * Fixed a crash (introduced in 0.60) when the final line in a
    file does not have a trailing newline and occurs more than
    once in the file.
* Sat Aug 31 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Packaging changes:
  * Disable cargo vendor service update to avoid breaking
    dependency changes and reenable tests.
  * Add cargo vendor filter to reduce vendor tarball size
    significantly.
* Thu Aug 29 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.60.0:
  * Fixed a crash (introduced in 0.59) when the final changed hunk
    included the last line of the file
  * Fixed an issue where files with no common content would show
    duplicate hunks
  * Fixed a performance issue when files had extremely long lines
    (e.g. 100,000+ characters).
- remove cargo_audit, as it's now included in cargo_vendor
- add new build dependency (libstdc++)
- exclude mdbook, so difftastic can be built for Leap
- disable tests for now, as too many fail, software still works
* Sun May 12 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.58.0:
  * Produces better diffs by preserving parsed structure, trading
    off showing fewer changes in case of parse errors
  * Update C, C++, CMake, CSS, Elm, Go, Lua and Python parsers
  * --strip-cr now defaults to on
  * add a manpage
  * Fix a memory leak and improved performance in some cases
  * Fix a crash when unable to detect the terminal width (eshell)
  * Considers $COLUMNS when detecting the terminal width
* Tue Apr  9 2024 Martin Schreiner <martin.schreiner@suse.com>
- 0.57.0:
  Parsing
  * Text file detection is now stricter, considering null bytes as a
    hint that files are binaries.
  Diffing
  * Fixed an issue where hidden files (filename starting with .) were
    ignored when diffing directories.
  * Scheme now uses the same slider heuristics as other lisps,
    preferring the outer delimiter.
  * Fixed an issue with line-based diffing where only the first line
    in a large changed region was highlighted. This was particularly
    noticeable when diffing brand new files.
  Display
  * Fixed an issue when reporting changes in binary files, where
    trailing whitespace was inconsistent with other changes shown.
* Sun Mar 24 2024 Gordon Leung <pirateclip@protonmail.com>
- 0.56.1:
  Parsing
  * Added support for Objective-C and VHDL.
  * Files starting with <?xml are now parsed as XML.
  * Fixed a munmap_chunk(): invalid pointer crash on parsing some large files,
  * particularly JSON.
  * Makefile*.in is now detected as Makefile syntax.
  * Improved shebang parsing with whitespace
  * Added support for Scheme and Smali.
  * 
  Diffing
  * Fixed an issue with runaway memory usage on text files with very long lines.
  Display
  * The default display width for tabs has changed to 4.
  * Fixed an issue where difftastic would sometimes output
    literal tabs rather than respecting the display width for tabs.
  * Fixed an issue where all files would show a permissions change
    when using difftastic with git difftool.
  * Fixed an issue with paths not showing the containing directory
    when using difftastic with git difftool.
  * Difftastic now correctly reports file permission changes when
    called from git diff.
  * Fixed an issue with the experimental JSON display mode where it
    ignored --skip-unchanged.
  * Fixed an issue with tabs not being replaced in single-column display.
* Mon Jan  8 2024 Andreas Stieger <andreas.stieger@gmx.de>
- 0.54.0:
  * Support reporting file permission changes
  * Support for Salesforce Apex, improve Clojure and Haskell
  * bug fixes
* Sun Nov 26 2023 Andreas Stieger <andreas.stieger@gmx.de>
- 0.53.1:
  * Parsing: Add support for SCSS,  Improve Kotlin support, and
    detect snap files (Jest snapshots) as JavaScript files
  * Fix an issue where adding or removing blank lines would be
    ignored by the textual diffing logic.
  * Directory diffing now respects .gitignore files.
  * New --sort-paths option for sorting files by path
  * New --strip-cr for improved diffing in mixed environment
  * The option --skip-unchanged now has a corresponding environment
    option DFT_SKIP_UNCHANGED
* Sun Oct 29 2023 Andreas Stieger <andreas.stieger@gmx.de>
- spec tweaks for submission
* Mon Oct  9 2023 munix9@googlemail.com
- update to version 0.52.0
